@@ -16,14 +16,13 @@ Instructions::Instructions(QWidget *parent) :
     ui->labelMain->setText(tr( "<b>Fresh Swap</b><br>\
                                Moves Swap to a fresh SD location<br>\
                                <b>Swap to Device</b><br>\
-                               Moves Swap to /dev/mmcblk0p3<br>\
+                               Moves Swap to Device<br>\
                                <b>Show Current</b><br>\
-                               Shows current swap location<br>\
+                               Shows current swap location(s)<br>\
                                <b>Check Usage</b><br>\
                                Checks current swap usage<br>\
-                               <b>Swaps MUST be located at:-</b><br>\
-                               <b>Device Backup</b> /dev/mmcblk0p3<br>\
-                               <b>SD Swaps</b> /dev/mmcblk1p2 and 1p3<br></b>"));
+                               <b>There MUST be two uSD swaps,</b><br>\
+                               <b>and one device swap minimum.</b>"));
 
 }
 
